@@ -1,63 +1,26 @@
 package Object::Container;
+use Any::Moose;
 
-use strict;
-use warnings;
-use parent qw(Class::Accessor::Fast Class::Singleton);
+our $VERSION = '0.01';
 
-use Carp;
-use Data::Util qw(is_invocant);
-use Exporter::AutoClean;
+extends any_moose('::Object'), 'Class::Singleton';
 
-our $VERSION = '0.09_01';
+has registered_classes => (
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub { {} },
+);
 
-__PACKAGE__->mk_accessors(qw/registered_classes objects/);
+has objects => (
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub { {} },
+);
 
-sub import {
-    my ($class, $name) = @_;
-    return unless $name;
-
-    my $caller = caller;
-    {
-        no strict 'refs';
-        if ($name =~ /^-base$/i) {
-            push @{"${caller}::ISA"}, $class;
-            my $r = $class->can('register');
-            Exporter::AutoClean->export(
-                $caller,
-                register => sub { $r->($caller, @_) },
-                preload  => sub {
-                    $caller->instance->get($_) for @_;
-                },
-                preload_all_except => sub {
-                    $caller->instance->load_all_except(@_);
-                },
-                preload_all => sub {
-                    $caller->instance->load_all;
-                },
-            );
-
-        }
-        else {
-            no strict 'refs';
-            *{"${caller}::${name}"} = sub {
-                my ($target) = @_;
-                return $target ? $class->get($target) : $class;
-            };
-        }
-    }
-}
-
-sub new {
-    $_[0]->SUPER::new( +{
-        registered_classes => +{},
-        objects => +{},
-    } );
-}
+no Any::Moose;
 
 # override Class::Singleton initializer
-sub _new_instance {
-    $_[0]->new;
-}
+sub _new_instance { shift->new(@_) }
 
 sub register {
     my ($self, $class, @rest) = @_;
@@ -77,70 +40,21 @@ sub register {
     $self->registered_classes->{$class} = $initializer;
 }
 
-sub unregister {
-    my ($self, $class) = @_;
-    $self = $self->instance unless ref $self;
-
-    delete $self->registered_classes->{$class} and $self->remove($class);
-}
-
 sub get {
     my ($self, $class) = @_;
     $self = $self->instance unless ref $self;
-    my $obj = $self->objects->{ $class } ||= do {
-        my $initializer = $self->registered_classes->{ $class };
-        $initializer ? $initializer->($self) : ();
-    } or croak qq["$class" is not registered in @{[ ref $self ]}];
-}
-
-sub remove {
-    my ($self, $class) = @_;
-    $self = $self->instance unless ref $self;
-    delete $self->objects->{ $class };
-}
-
-sub load_all {
-    my ($self) = @_;
-    $self->load_all_except;
-}
-
-sub load_all_except {
-    my ($self, @except) = @_;
-
-    for my $class (keys %{ $self->registered_classes }) {
-        next if grep { $class eq $_ } @except;
-        $self->get($class);
-    }
-}
-
-# taken from Mouse::Uti
-sub _try_load_one_class {
-    my $class = shift;
-
-    return '' if is_invocant($class);
-
-    $class  =~ s{::}{/}g;
-    $class .= '.pm';
-
-    return do {
-        local $@;
-        eval { require $class };
-        $@;
-    };
+    my $obj = $self->objects->{ $class } ||= $self->registered_classes->{$class}->()
+        or die qq["$class" is not registered in @{[ ref $self ]}];
 }
 
 sub ensure_class_loaded {
     my ($self, $class) = @_;
-    my $e = _try_load_one_class($class);
-    Carp::confess "Could not load class ($class) because : $e" if $e;
-
-    return $class;
+    Any::Moose::load_class($class) unless Any::Moose::is_class_loaded($class);
 }
 
-1;
-__END__
+__PACKAGE__->meta->make_immutable;
 
-=for stopwords DSL OO runtime singletonize unregister
+__END__
 
 =head1 NAME
 
@@ -172,23 +86,6 @@ Object::Container - simple object container
     # With singleton interface, you can use register/get method as class method
     Object::Container->register('WWW::Mechanize');
     my $mech = Object::Container->get('WWW::Mechanize');
-    
-    # Export singleton interface
-    use Object::Container 'container';
-    container->register('WWW::Mechanize');
-    my $mech = container->get('WWW::Mechanize');
-    my $mech = container('WWW::Mechanize'); # save as above
-    
-    # Subclassing singleton interface
-    package MyContainer;
-    use Object::Container '-base';
-    
-    register mech => sub { WWW::Mechanize->new };
-    
-    # use it
-    use MyContainer 'con';
-    
-    con('mech')->get('http://example.com');
 
 =head1 DESCRIPTION
 
@@ -227,37 +124,6 @@ When you want use multiple container with Singleton interface, you have to creat
     MyContainer1->get('WWW::Mechanize');
     MyContainer2->get('WWW::Mechanize');
 
-=head2 Singleton interface with EXPORT function for lazy people
-
-If you are lazy person, and don't want to write something long code like:
-
-    MyContainer->get('WWW::Mechanize');
-
-This module provide export functions to shorten this.
-If you use your container with function name, the function will be exported and act as container:
-
-    use MyContainer 'container';
-    
-    container->register(...);
-    
-    container->get(...);
-    container(...);             # shortcut to ->get(...);
-
-=head2 Subclassing singleton interface for lazy people
-
-If you are lazy person, and don't want to write something long code in your subclass like:
-
-    __PACKAGE__->register( ... );
-
-Instead of above, this module provide subclassing interface.
-To do this, you need to write below code to subclass instead of C<use base>.
-
-    use Object::Container '-base';
-
-And then you can register your object via DSL functions:
-
-    register ua => sub { LWP::UserAgent->new };
-
 =head2 lazy loading and resolve dependencies
 
 The object that is registered by 'register' method is not initialized until calling 'get' method.
@@ -283,10 +149,6 @@ In that case, only LWP::UserAgent and HTTP::Cookies are initialized.
 
 =head1 METHODS
 
-=head2 new
-
-Do not use it. use instance method.
-
 =head2 register( $class, @args )
 
 =head2 register( $class_or_name, $initialize_code )
@@ -318,9 +180,6 @@ With last way you can pass any name to first argument instead of class name.
     Object::Container->register('ua1', sub { LWP::UserAgent->new });
     Object::Container->register('ua2', sub { LWP::UserAgent->new });
 
-=head2 unregister($class_or_name)
-
-Unregister classes from container.
 
 =head2 get($class_or_name)
 
@@ -328,12 +187,6 @@ Get the object that registered by 'register' method.
 
 First argument is same as 'register' method.
 
-=head2 remove($class_or_name)
-
-Remove the cached object that is created at C<get> method above.
-
-Return value is the deleted object if it's exists.
-
 =head2 ensure_class_loaded($class)
 
 This is utility method that load $class if $class is not loaded.
